Module reader

Module reader 

Streaming ZIP reader - reads ZIP files without loading entire central directory

This is a minimal ZIP reader that can extract specific files from a ZIP archive without loading the entire central directory into memory.

Re-exports

pub use crate::format::ZipEntry;

Structs

StreamingZipReader
Streaming ZIP archive reader with adaptive buffering